<?php

namespace Litepci\Control\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Control\Models\Compliancetype;

class CompliancetypePolicy
{

    /**
     * Determine if the given user can view the compliancetype.
     *
     * @param UserPolicy $user
     * @param Compliancetype $compliancetype
     *
     * @return bool
     */
    public function view(UserPolicy $user, Compliancetype $compliancetype)
    {
        if ($user->canDo('control.compliancetype.view') && $user->isAdmin()) {
            return true;
        }

        return $compliancetype->user_id == user_id() && $compliancetype->user_type == user_type();
    }

    /**
     * Determine if the given user can create a compliancetype.
     *
     * @param UserPolicy $user
     * @param Compliancetype $compliancetype
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('control.compliancetype.create');
    }

    /**
     * Determine if the given user can update the given compliancetype.
     *
     * @param UserPolicy $user
     * @param Compliancetype $compliancetype
     *
     * @return bool
     */
    public function update(UserPolicy $user, Compliancetype $compliancetype)
    {
        if ($user->canDo('control.compliancetype.edit') && $user->isAdmin()) {
            return true;
        }

        return $compliancetype->user_id == user_id() && $compliancetype->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given compliancetype.
     *
     * @param UserPolicy $user
     * @param Compliancetype $compliancetype
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Compliancetype $compliancetype)
    {
        return $compliancetype->user_id == user_id() && $compliancetype->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given compliancetype.
     *
     * @param UserPolicy $user
     * @param Compliancetype $compliancetype
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Compliancetype $compliancetype)
    {
        if ($user->canDo('control.compliancetype.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given compliancetype.
     *
     * @param UserPolicy $user
     * @param Compliancetype $compliancetype
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Compliancetype $compliancetype)
    {
        if ($user->canDo('control.compliancetype.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
